skhubness.reduction.MutualProximity
===================================

.. currentmodule:: skhubness.reduction

.. autoclass:: MutualProximity

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~MutualProximity.__init__
      ~MutualProximity.fit
      ~MutualProximity.transform
   
   

   
   
   